KeyEvent class final

A decoded terminal key sequence.

sequence is the original terminal sequence that produced the event. binding is the canonical key binding string used by Keypass.

Constructors

KeyEvent({required String sequence, required String key, bool ctrl = false, bool meta = false, bool shift = false})
Creates a key event.
const
KeyEvent.fromSequence(String sequence)
Decodes a complete terminal key sequence.
factory

Properties

binding String
Canonical key binding string.
no setter
ctrl bool
Whether the Control modifier was pressed.
final
hashCode int
The hash code for this object.
no setteroverride
key String
The normalized key token.
final
meta bool
Whether the Meta/Alt modifier was pressed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequence String
The original terminal sequence.
final
shift bool
Whether the Shift modifier was pressed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override