Prompt class final

Basic prompt flow built on top of Readline.

Available extensions

Constructors

Prompt({required Readline readline})
Creates a prompt instance from an existing readline.
Prompt.stdio()
Creates a prompt instance backed by process stdio.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Closes resources owned by this prompt.
confirm(String message, {bool? defaultValue}) Future<bool?>

Available on Prompt, provided by the PromptUtils extension

Asks a yes/no question.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text(String message, {String? defaultValue}) Future<String?>
Asks for one line of text.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited