Readline class final
Interactive line input with editing-friendly terminal behavior.
Constructors
-
Readline({required Stream<
List< input, required StringSink output, int historyLimit = 100, Iterable<int> >String> history = const <String>[]}) - Creates a readline instance from injected input and output streams.
-
Readline.stdio({Stdin? input, StringSink? output, int historyLimit = 100, Iterable<
String> history = const <String>[]}) -
Creates a readline instance backed by process stdio.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Stops reading from the input stream.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readLine(
{String prompt = ''}) → Future< String?> - Reads one edited line.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited